@@ -298,12 +298,14 @@ void liqcell_setrect_autoscale(liqcell *self,int x,int y,int w,int h,float sx,fl
 
 void 	liqcell_adjustpos(liqcell *self,int dx,int dy)
 {
+	if(dx==0 && dy==0)return;
 	self->x+=dx;
 	self->y+=dy;
 	liqcell_handlerrun(self,"move",NULL);
 }
 void 	liqcell_adjustsize(liqcell *self,int dw,int dh)
 {
+	if(dw==0 && dh==0)return;
 	self->w+=dw;
 	self->h+=dh;
 	liqcell_handlerrun(self,"resize",NULL);
@@ -910,6 +912,34 @@ liqcell* liqcell_child_append(liqcell *self,liqcell *c)
 
 
 
+int liqcell_child_removeall(liqcell *self)
+{
+	liqcell *c=liqcell_getlinkchild(self);
+	while(  c   )
+	{
+		liqcell *d = c->linknext;
+		liqcell_child_remove(self,c);
+		c=d;
+	}
+	return 0;
+}
+
+
+
+int liqcell_child_removeallvisual(liqcell *self)
+{
+	liqcell *c=liqcell_getlinkchild(self);
+	while(  c   )
+	{
+		liqcell *d = c->linknext;
+		if( liqcell_getflagvisual(c) ) liqcell_child_remove(self,c);
+		c=d;
+	}
+	return 0;
+}
+
+
+
 int  liqcell_child_remove(liqcell *self,liqcell *child)
 {
 	// remove specified child, heh, leave this for now
@@ -1093,7 +1123,22 @@ liqcell* liqcell_child_insertsortedbyname(liqcell *self,liqcell * ch,int sortpos
 //	return liqcell_findfirst(self->linkchild,query);
 //}
 
+liqcell* liqcell_child_lookup_simple(liqcell *self,char *name)
+{
+	// 20090615_031345 lcuk : ignore dot name in this variation
 
+	liqcell *c=self->linkchild;
+	while(c)
+	{
+		//liqapp_log("test %s==%s == %i",c->name,name,strcmp(c->name,name));
+		if(strcmp(c->name,name)==0)
+		{
+			return c;
+		}
+		c=c->linknext;
+	}
+	return NULL;
+}
 liqcell* liqcell_child_lookup(liqcell *self,char *name)
 {
 	// find a named child
